@@ -6,11 +6,11 @@ from flaky import flaky
 
 import pylast
 
-from .test_pylast import PyLastTestCase, load_secrets
+from .test_pylast import load_secrets
 
 
 @flaky(max_runs=3, min_passes=1)
-class TestPyLastWithLibreFm(PyLastTestCase):
+class TestPyLastWithLibreFm:
     """Own class for Libre.fm because we don't need the Last.fm setUp"""
 
     def test_libre_fm(self) -> None:
@@ -38,4 +38,4 @@ class TestPyLastWithLibreFm(PyLastTestCase):
         representation = repr(network)
 
         # Assert
-        self.assert_startswith(representation, "pylast.LibreFMNetwork(")
+        assert representation.startswith("pylast.LibreFMNetwork(")
